@@ -14,6 +14,8 @@ import getpass
 import traceback
 import readline
 
+
+
 d_type = "postgresql"
 d_host = ""
 d_port = ""
@@ -149,7 +151,7 @@ class baseCmd(cmd.Cmd):
 	def help_psql(self):
 		print "\trun postgresql client. psql required"
 	def help_csvloader(self):
-		print "\tload a local CSV file into a server-side BigObject table\n\tex. csvloader <csv_file> <bt_url>"
+		print "\tload a local CSV file into a server-side BigObject table\n\tex. csvloader <csv_file> <bt_name>"
 	def help_sethost(self):
 		print "\tset host name"
 	def help_setport(self):
@@ -158,7 +160,8 @@ class baseCmd(cmd.Cmd):
 		print "\tset timeout value"
 
 class associateCmd(cmd.Cmd):
-	assocword = [ 'associate', 'association', 'with', 'from' , 'by' , 'where' , 'query' , 'tables' , 'associates', 'from', 'by', 'group by' , 'where' , 'tree' , 'table' , 'fact' , 'dim']
+	#assocword = [ 'associate', 'association', 'with', 'from' , 'by' , 'where' , 'query' , 'tables' , 'associates', 'from', 'by', 'group by' , 'where' , 'tree' , 'table' , 'fact' , 'dim']
+	assocword = [ 'association', 'with', 'from' , 'by' , 'where' , 'query' , 'tables' , 'from', 'by', 'group by' , 'where' , 'tree' , 'table' , 'fact' , 'dim']
 	#algorithm_set = ['cos_sim', 'aggr']
 	def __init__(self):
 		cmd.Cmd.__init__(self)
@@ -303,8 +306,12 @@ class associateCmd(cmd.Cmd):
 
 
 	def do_create(self, line):
+		#print rpcshell.shell(self.host, self.port ,self.token, "assoc" , "build " + line, self.timeout)
 		print rpcshell.shell(self.host, self.port ,self.token, "assoc" , "create " + line, self.timeout)
 
+	def do_build(self, line):
+		#print rpcshell.shell(self.host, self.port ,self.token, "assoc" , "build " + line, self.timeout)
+		print rpcshell.shell(self.host, self.port ,self.token, "assoc" , "create " + line, self.timeout)
         
         def do_ask(self, line):
                 if "about" in line:
@@ -348,19 +355,19 @@ class associateCmd(cmd.Cmd):
 		#	print boshCmd.getinfo(self.host, self.port ,self.token, "get_mbt_list" , "" , self.timeout)
 		#elif line == "algorithms":
 		#	print self.algorithm_set
-		elif line == "associates":
+		elif line == "association":
 			print boshCmd.getinfo(self.host, self.port ,self.token, "get_qbo_list" , "" , self.timeout)
 		else:
-			print "show [tables | associates ]"
+			print "show [tables | association ]"
 	def do_desc(self, line):
-		if line[:10] == "associate ":
-			print boshCmd.getinfo(self.host, self.port ,self.token, "get_qbo_info" , line[10:], self.timeout)
+		if line[:12] == "association ":
+			print boshCmd.getinfo(self.host, self.port ,self.token, "get_qbo_info" , line[12:], self.timeout)
 		#elif line[:7] == "matrix ":
 		#	print boshCmd.getinfo(self.host, self.port ,self.token, "get_mbt_info" , line[7:], self.timeout)
 		elif line != "":
 			print boshCmd.getinfo(self.host, self.port ,self.token, "get_table_schema" , line, self.timeout)
 		else:
-			print "desc [associate] <name>"
+			print "desc [association] <name>"
 	
 	#def do_list(self, line):
 	#	name = line.split()
@@ -408,6 +415,31 @@ class associateCmd(cmd.Cmd):
 		newcmd.prompt = self.prompt[:len(self.prompt)-1] + ":admin>"
 		newcmd.cmdloop()
 
+        def do_print(self,line):
+               command=line.split(">>")
+               if len(command)==2:
+                      doInvoke=False
+                      outfile=str()
+                      if "@" in command[1]:
+                            outfile=command[1][command[1].find("@")+1:].strip()
+                            if len(outfile)==0:
+                                   return "*** FILENAME required after \">>@\""
+                            doInvoke=True
+                      else:  
+                            outfile=command[1].strip()
+                      outfile=tools.redirectFiles(globals()[command[0].strip()],outfile)
+                      if outfile=="BADINPUT":
+                            return "*** cancel outputting the file"
+                      if doInvoke:
+                            tools.invokeFiles(outfile)
+
+               else:
+	             try:
+		           exec("print "+line) in globals()
+		     except:
+		           traceback.print_exc()
+
+                       
 	def writehist(self):
 		import readline
 		readline.set_history_length(80)
@@ -441,7 +473,9 @@ class associateCmd(cmd.Cmd):
                 
                 #print "final str:" ,new_str
                 return new_str
-               
+              
+
+ 
 	def help_column(self):
 		print "\tex. b=column 1 in a \n\tb=column 2,4 in a"
 	def help_row(self):
@@ -462,9 +496,9 @@ class associateCmd(cmd.Cmd):
 	def help_query(self):
 		tools.print_help_string('assoc_query')
 	def help_show(self):
-		print "\tlist resource in the shell\n\tex. show [tables | associates ]"
+		print "\tlist resource in the shell\n\tex. show [tables | association ]"
 	def help_desc(self):
-		print "\tshow meta-information of a resource\n\tex. desc [associate] <name>"
+		print "\tshow meta-information of a resource\n\tex. desc [association] <name>"
 
 class sqlCmd(cmd.Cmd):
 	SELECTword = [ 'from', 'by', 'group by' , 'where' , 'sum' , 'count' , 'distinct' ]
@@ -635,6 +669,7 @@ def main():
 	#cmd = baseCmd()
 	#cmd.setremote(host, port , token, "bosh>")
 	newcmd = associateCmd()
+	newcmd.bosrv_url = bo_url
 	newcmd.host = host
 	newcmd.port = port
 	newcmd.token = token
